@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1711 2025/05/02 06:19:42 rsadowski Exp $
+# $OpenBSD: Quirks.pm,v 1.1729 2025/06/22 12:28:32 daniel Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -63,6 +63,7 @@ my $base_exceptions = {
 # 7.7
 	'p5-Test2-Suite' => '/usr/libdata/perl5/Test2/Suite.pm',
 	'p5-Term-Table' => '/usr/libdata/perl5/Term/Table.pm',
+	'pkgconf' => '/usr/bin/pkg-config',
 };
 
 my $stem_extensions = {
@@ -623,6 +624,12 @@ my $stem_extensions = {
 	'libkcompactdisc-kf5' => 'kf6-libkcompactdisc',
 	'c-icap-clamav' => 'c-icap-modules',
 	'c-icap-urlcheck' => 'c-icap-modules',
+# 7.8
+	'coq' => 'rocq',
+	'totem' => 'showtime',
+	'py-numpy' => 'py3-numpy',
+	'py-Pillow' => 'py3-Pillow',
+	'py-opengl' => 'py3-opengl',
 };
 
 my $obsolete_reason = {};
@@ -1249,6 +1256,20 @@ setup_obsolete_reason(
 	5 => 'xsd',
 	29 => 'fastnetmon',
 	3 => 'kross-interpreters-kf5',
+	3 => 'py3-notmuch',
+	3 => 'pop3d',
+	3 => 'myrddin',
+	3 => 'ksql',
+	6 => 'py-elasticsearch-curator',
+	6 => 'py-ipython_genutils',
+# 7.8
+	6 => 'gnome-video-effects',
+	3 => 'gnome-dictionary',
+	3 => 'gnome-photos',
+	3 => 'tsung',
+	3 => 'mysticmine',
+	3 => 'fretsonfire',
+	3 => 'py-lpsolve',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
